import { createApp } from "vue";
import { createStore } from "vuex"
import App from "./App.vue";
import ToggleButton from "./components/ToggleButton.vue"

const store = createStore({
    state() {
        return {
            /** @type {Map<String, String>} */
            translations: new Map()
        }
    },
    mutations: {
        setTranslations(state, translations) {
            state.translations = translations;
        }
    }
});

const app = createApp(App);

app.use(store);
app.component("ToggleButton", ToggleButton)
    .mount("#app");

/* === Get interface translations === */

/** @type {Map<String, String>} */
const translations = new Map();

/* We might be running under Greenstone, so pull the translations from there if so */
/* eslint-disable no-undef */
if (typeof gs !== "undefined" && gs.text && gs.text.atea && gs.text.atea.ocr) {
    for (const key in gs.text.atea.ocr) {
        translations.set(key, gs.text.atea.ocr[key]);
    }

    store.commit("setTranslations", translations)
}
/* eslint-enable no-undef */
else {
    fetch("resources/interface_atea.properties")
        .then(
            async response => {
                const responseText = await response.text();
                const responseTranslations = responseText.split("\n");

                for (const translation of responseTranslations) {
                    const keyvalue = translation.split("=");

                    if (keyvalue.length !== 2) {
                        continue;
                    }

                    const namespace = keyvalue[0].split(".");
                    if (namespace.length !== 3 || namespace[1] !== "ocr") {
                        continue;
                    }

                    translations.set(namespace[namespace.length - 1], keyvalue[1]);
                }

                store.commit("setTranslations", translations)
            }
        );
}
